You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by ch...@apache.org on 2019/05/08 03:48:55 UTC

[mesos] branch master updated: Fixed flakiness in 'RetryRpcWithExponentialBackoff'.

This is an automated email from the ASF dual-hosted git repository.

chhsiao pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/mesos.git


The following commit(s) were added to refs/heads/master by this push:
     new a87b66a  Fixed flakiness in 'RetryRpcWithExponentialBackoff'.
a87b66a is described below

commit a87b66aeed840abbf06a2a300d85e8098e3d6fd4
Author: Jan Schlicht <ja...@mesosphere.io>
AuthorDate: Tue May 7 20:40:21 2019 -0700

    Fixed flakiness in 'RetryRpcWithExponentialBackoff'.
    
    Under some circumstances, offers would be filtered, resulting in the
    test being stuck while waiting for offers. This has been resolved by
    settling the clock before accepting new offers.
    
    Review: https://reviews.apache.org/r/70184/
---
 src/tests/storage_local_resource_provider_tests.cpp | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/src/tests/storage_local_resource_provider_tests.cpp b/src/tests/storage_local_resource_provider_tests.cpp
index ec2222d..ba55728 100644
--- a/src/tests/storage_local_resource_provider_tests.cpp
+++ b/src/tests/storage_local_resource_provider_tests.cpp
@@ -5861,7 +5861,9 @@ TEST_P(StorageLocalResourceProviderTest, RetryRpcWithExponentialBackoff)
   AWAIT_READY(updateOperationStatus);
   EXPECT_EQ(OPERATION_FINISHED, updateOperationStatus->status().state());
 
-  // Advance the clock to trigger a batch allocation.
+  // Settle the clock to recover the created disk, then advance the clock to
+  // trigger a batch allocation.
+  Clock::settle();
   Clock::advance(masterFlags.allocation_interval);
 
   AWAIT_READY(offers);